@@ -2,7 +2,6 @@ from hdx.location.adminone import AdminOne
 from hdx.utilities.dateparse import parse_date
 
 from hdx.scraper.base_scraper import BaseScraper
-from hdx.scraper.configurable.aggregator import Aggregator
 from hdx.scraper.outputs.json import JsonFile
 from hdx.scraper.outputs.update_tabs import (
     get_regional_rows,
@@ -90,14 +89,14 @@ class TestScrapersRegionalToplevel:
         configuration_hxl = configuration["aggregation_hxl"]
         aggregator_configuration = configuration_hxl[f"aggregation_{level}"]
         adm_aggregation = ("AFG", "PSE")
-        scrapers = Aggregator.get_scrapers(
+        names = runner.add_aggregators(
+            True,
             aggregator_configuration,
             "national",
             level,
             adm_aggregation,
-            runner,
+            force_add_to_run=True,
         )
-        names = runner.add_customs(scrapers, add_to_run=True)
         assert names == [
             f"population_{level}",
             f"affected_infected_per100000_{level}",
@@ -127,14 +126,14 @@ class TestScrapersRegionalToplevel:
 
         regions = ("ROAP",)
         aggregator_configuration = configuration_hxl["aggregation_sum"]
-        scrapers = Aggregator.get_scrapers(
+        regional_names = runner.add_aggregators(
+            True,
             aggregator_configuration,
             "national",
             "regional",
             {"AFG": regions, "PSE": ("somewhere",)},
-            runner,
+            force_add_to_run=True,
         )
-        regional_names = runner.add_customs(scrapers, add_to_run=True)
         runner.run(regional_names)
         regional_rows = get_regional_rows(
             runner, regions, names=regional_names
